==> oqupy-0.2.0.tar.gz: oqupy-0.2.0/AUTHORS.md <==
List of Authors
===============

This open source project has been started by [Gerald E. Fux](https://github.com/gefux) in 2020 as a member of the [TEMPO collaboration](https://github.com/tempoCollaboration).

Members of the TEMPO collaboration:
-----------------------------------

- Kristín Arnardóttir (*University of St Andrews*) <kristinbjorga@gmail.com>
- [Piper Fowler-Wright](https://github.com/piperfw) (*University of St Andrews*) <pfw1@st-andrews.ac.uk>
- [Gerald E. Fux](https://github.com/gefux) (*University of St Andrews*) <gf52@st-andrews.ac.uk>
- [Erik Gauger](https://github.com/erikgauger) (*Heriot-Watt University*) <e.gauger@hw.ac.uk>
- [Dominic Gribben](https://github.com/djgribben) (*University of St Andrews*)
- Jonathan Keeling (*University of St Andrews*) <jmjk@st-andrews.ac.uk>
- Dainius Kilda (*Max Planck Institute of Quantum Optics*)
- [Peter Kirton](https://github.com/peterkirton) (*University of Strathclyde*) <peter.kirton@strath.ac.uk>
- [Thibaut Lacroix](https://github.com/tfmlaX) (*University of St Andrews*) <tfml1@st-andrews.ac.uk>
- Brendon W. Lovett (*University of St Andrews*) <bwl4@st-andrews.ac.uk>

Project administrators:
-----------------------

- [Gerald E. Fux](https://github.com/gefux) (<gf52@st-andrews.ac.uk>)
- Jonathan Keeling (<jmjk@st-andrews.ac.uk>)
- Brendon W. Lovett (<bwl4@st-andrews.ac.uk>)

Project maintainers:
--------------------
- [Gerald E. Fux](https://github.com/gefux) (<gf52@st-andrews.ac.uk>)
- [Peter Kirton](https://github.com/peterkirton) (<peter.kirton@strath.ac.uk>)


Major code contributions:
=========================

**Version 0.2.0**
- [Gerald E. Fux](https://github.com/gefux): Chains of open quantum systems [Fux2022].
- Dainius Kilda: Precursor code for chains of open quantum systems [Fux2022].
- [Dominic Gribben](https://github.com/djgribben): Bath dynamics extension [Gribben2021a].
- [Dominic Gribben](https://github.com/djgribben): Multiple environments extension [Gribben2021b].

**Version 0.1.2 (TimeEvolvingMPO)**
- [Gerald E. Fux](https://github.com/gefux): Improved memory cut-off [Strathearn2017].

**Version 0.1.1 (TimeEvolvingMPO)**
- No major code contributions in this version.

**Version 0.1.0 (TimeEvolvingMPO)**
- [Gerald E. Fux](https://github.com/gefux): Implement process tensor TEMPO (API and backend) [Fux2021].
- [Gerald E. Fux](https://github.com/gefux): Implement core TEMPO functionality (API and backend) [Strathearn2018].
- [Gerald E. Fux](https://github.com/gefux): Setup Project (CI, API design, project planning, etc.).

==> oqupy-0.3.3.tar.gz: oqupy-0.3.3/AUTHORS.md <==
Authors & Acknowledgements
==========================

Lead developer since 2020 (start of the project): [Gerald E. Fux](https://github.com/gefux)

Major code contributions
------------------------

**Version 0.3.0**
- [Piper Fowler-Wright](https://github.com/piperfw): Open quantum systems with mean-field evolution [FowlerWright2021]

**Version 0.2.0**
- [Gerald E. Fux](https://github.com/gefux): Chains of open quantum systems [Fux2022].
- Dainius Kilda: Precursor code for chains of open quantum systems [Fux2022].
- [Dominic Gribben](https://github.com/djgribben): Bath dynamics extension [Gribben2021].
- [Dominic Gribben](https://github.com/djgribben): Multiple environments extension [Gribben2022].

**Version 0.1.2 (TimeEvolvingMPO)**
- [Gerald E. Fux](https://github.com/gefux): Improved memory cut-off [Strathearn2017].

**Version 0.1.1 (TimeEvolvingMPO)**
- No major code contributions in this version.

**Version 0.1.0 (TimeEvolvingMPO)**
- [Gerald E. Fux](https://github.com/gefux): Implement process tensor TEMPO (API and backend) [Fux2021].
- [Gerald E. Fux](https://github.com/gefux): Implement core TEMPO functionality (API and backend) [Strathearn2018].
- [Gerald E. Fux](https://github.com/gefux): Setup Project (CI, API design, project planning, etc.).


Acknowledgements
----------------

**Members of the TEMPO collaboration:**
- Kristín Arnardóttir (*University of St Andrews*) <kristinbjorga@gmail.com>
- [Piper Fowler-Wright](https://github.com/piperfw) (*University of St Andrews*) <pfw1@st-andrews.ac.uk>
- [Gerald E. Fux](https://github.com/gefux) (*University of St Andrews*) <gf52@st-andrews.ac.uk>
- [Erik Gauger](https://github.com/erikgauger) (*Heriot-Watt University*) <e.gauger@hw.ac.uk>
- [Dominic Gribben](https://github.com/djgribben) (*University of St Andrews*)
- Jonathan Keeling (*University of St Andrews*) <jmjk@st-andrews.ac.uk>
- Dainius Kilda (*Max Planck Institute of Quantum Optics*)
- [Peter Kirton](https://github.com/peterkirton) (*University of Strathclyde*) <peter.kirton@strath.ac.uk>
- [Thibaut Lacroix](https://github.com/tfmlaX) (*University of St Andrews*) <tfml1@st-andrews.ac.uk>
- Brendon W. Lovett (*University of St Andrews*) <bwl4@st-andrews.ac.uk>

**Project administrators:**
- [Gerald E. Fux](https://github.com/gefux) (<gf52@st-andrews.ac.uk>)
- Jonathan Keeling (<jmjk@st-andrews.ac.uk>)
- Brendon W. Lovett (<bwl4@st-andrews.ac.uk>)


**Project maintainers:**
- [Gerald E. Fux](https://github.com/gefux) (<gf52@st-andrews.ac.uk>)
- [Peter Kirton](https://github.com/peterkirton) (<peter.kirton@strath.ac.uk>)
